@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use CPAN::Meta;
 use Carp;
@@ -25,6 +25,7 @@ use Specio::Library::Numeric;
 use Specio::Library::Perl;
 use Specio::Library::String;
 use Try::Tiny;
+use URI::Escape qw( uri_escape );
 
 use Moo;
 use MooX::Options;
@@ -112,7 +113,8 @@ option dist => (
 option force => (
     is      => 'ro',
     isa     => t('Bool'),
-    default => 0,
+    lazy    => 1,
+    default => sub { $_[0]->test ? 1 : 0 },
     doc     => 'Create issues in GitHub even if one already exists.',
 );
 
@@ -120,7 +122,8 @@ option resolve => (
     is          => 'ro',
     isa         => t('Bool'),
     negativable => 1,
-    default     => 1,
+    lazy        => 1,
+    default     => sub { $_[0]->test ? 0 : 1 },
     doc =>
         'Set this to false to to disable resolving RT tickets as they are converted.',
 );
@@ -133,6 +136,17 @@ option ticket => (
     doc       => 'Only operate on the given RT ticket.',
 );
 
+option test => (
+    is      => 'ro',
+    isa     => t('Bool'),
+    lazy    => 1,
+    default => 0,
+    doc =>
+        'Run in test mode. This is equivalent to setting --no-resolve and --force.'
+        . ' It also changes how GitHub tickets are formatted to avoid including'
+        . ' @mentions of other people so they do not get a flood of email while you test.',
+);
+
 has _default_dist_name => (
     is      => 'ro',
     isa     => t('Str'),
@@ -186,6 +200,22 @@ sub run {
     my $self = shift;
 
     $self->_ensure_all_config;
+
+    my $msg = sprintf(
+        'Converting %s from the %s RT queue to the %s/%s GitHub repo.',
+        ( $self->ticket ? 'ticket #' . $self->ticket : 'all tickets' ),
+        $self->dist,
+        $self->github_user,
+        $self->repo
+    );
+    say $msg or die $!;
+    if ( $self->resolve ) {
+        say 'Will resolve all RT tickets.' or die $!;
+    }
+    unless ( $self->force ) {
+        say 'Will skip tickets that are already converted.' or die $!;
+    }
+
     $self->_convert_tickets;
 
     return 0;
@@ -329,7 +359,7 @@ sub _convert_tickets {
     my $query = sprintf( <<'EOF', $self->dist );
 Queue = '%s'
 and
-( Status = 'new' or Status = 'open' or Status = 'stalled')
+( Status = 'new' or Status = 'open' or Status = 'stalled' or Status = 'patched')
 EOF
     $query .= sprintf( 'and id = %s', $self->ticket ) if $self->_has_ticket;
 
@@ -428,10 +458,10 @@ sub _extract_ticket_data {
     my $body
         = "Migrated from [rt.cpan.org #$id](https://rt.cpan.org/Ticket/Display.html?id=$id) (status was '$status')\n";
 
-    $body .= "\nRequesters:\n";
+    $body .= "\nRequestors:\n";
     $body .= join q{},
         map {"* $_\n"}
-        map { $self->_maybe_tag_email($_) } $ticket->requesters;
+        map { $self->_maybe_tag_email($_) } $ticket->requestors;
 
     my @attach_links;
     my $attach = $ticket->attachments->get_iterator;
@@ -439,8 +469,13 @@ sub _extract_ticket_data {
         my $xact   = $i->transaction_id;
         my $att_id = $i->id;
         my $name   = $i->file_name or next;
-        push @attach_links,
-            "[$name](https://rt.cpan.org/Ticket/Attachment/$xact/$att_id/$name)";
+        push @attach_links, sprintf(
+            '[%s](https://rt.cpan.org/Ticket/Attachment/%s/%s/%s)',
+            $name,
+            $xact,
+            $att_id,
+            uri_escape($name),
+        );
     }
     if (@attach_links) {
         my $attach_list = join( q{}, map {"* $_\n"} @attach_links );
@@ -503,7 +538,10 @@ sub _maybe_tag_email {
 
     my $text         = $email;
     my $contributors = $self->_contributor_map;
-    $text .= ' (@' . $contributors->{ lc $email } . ')'
+    $text
+        .= ' (@'
+        . ( $self->test ? q{ } : q{} )
+        . $contributors->{ lc $email } . ')'
         if $contributors->{ lc $email };
 
     return $text;
@@ -618,6 +656,79 @@ sub _close_rt_ticket {
     say "Closed ticket #$id on RT" or die $!;
 }
 
+if ( RT::Client::REST->VERSION <= 0.50 ) {
+    no warnings 'redefine';
+
+    ## no critic (ValuesAndExpressions::ProhibitInterpolationOfLiterals, RegularExpressions::ProhibitUnusualDelimiters, ValuesAndExpressions::ProhibitCommaSeparatedStatements)
+
+#<<<
+    *RT::Client::REST::Object::from_form = sub {
+    my $self = shift;
+
+    unless (@_) {
+        RT::Client::REST::Object::NoValuesProvidedException->throw;
+    }
+
+    my $hash = shift;
+
+    unless ('HASH' eq ref($hash)) {
+        RT::Client::REST::Object::InvalidValueException->throw(
+            "Expecting a hash reference as argument to 'from_form'",
+        );
+    }
+
+    # lowercase hash keys
+    my $i = 0;
+    $hash = { map { ($i++ & 1) ? $_ : lc } %$hash };
+
+    my $attributes = $self->_attributes;
+    my %rest2attr;  # Mapping of REST names to our attributes;
+    while (my ($attr, $value) = each(%$attributes)) {
+        my $rest_name = (exists($attributes->{$attr}{rest_name}) ?
+                         lc($attributes->{$attr}{rest_name}) : $attr);
+        $rest2attr{$rest_name} = $attr;
+    }
+
+    # Now set attributes:
+    while (my ($key, $value) = each(%$hash)) {
+        # Handle custom fields, ideally /(?(1)})/ would be appened to RE
+    if( $key =~ m%^(?:cf|customfield)(?:-|\.\{)([#\s\w_:()?/-]+)% ){
+        $key = $1;
+
+            # XXX very sketchy. Will fail on long form data e.g; wiki CF
+            if ($value =~ /,/) {
+                $value = [ split(/\s*,\s*/, $value) ];
+            }
+
+            $self->cf($key, $value);
+            next;
+        }
+
+        unless (exists($rest2attr{$key})) {
+            warn "Unknown key: $key\n";
+            next;
+        }
+
+    # Fix for https://rt.cpan.org/Ticket/Display.html?id=118729
+        if ($key ne 'content' && $value =~ m/not set/i) {
+            $value = undef;
+        }
+
+        my $method = $rest2attr{$key};
+        if (exists($attributes->{$method}{form2value})) {
+            $value = $attributes->{$method}{form2value}($value);
+        } elsif ($attributes->{$method}{list}) {
+            $value = [split(/\s*,\s*/, $value)],
+        }
+
+        $self->$method($value);
+    }
+
+    return;
+}
+#>>>
+}
+
 1;
 
 # ABSTRACT: Convert rt.cpan.org tickets to GitHub issues
@@ -632,7 +743,7 @@ RTx::ToGitHub - Convert rt.cpan.org tickets to GitHub issues
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -654,7 +765,7 @@ config> for needed info.
 =item 2. Make GitHub issues for each RT ticket
 
 The body of the ticket will be the new issue body, with replies converted to
-comments. Requesters and others participating in the discussion will be
+comments. Requestors and others participating in the discussion will be
 converted to C<@username> mentions on GitHub. The conversion is based on a
 one-time data dump made by pulling author data from MetaCPAN to make an email
 address to GitHub username map. Patches to this map are welcome.
@@ -738,8 +849,7 @@ script at L<https://github.com/dagolden/zzz-rt-to-github>.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=RTx-ToGitHub>
-(or L<bug-rtx-togithub@rt.cpan.org|mailto:bug-rtx-togithub@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/RTx-ToGitHub/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
@@ -764,6 +874,12 @@ button at L<http://www.urth.org/~autarch/fs-donation.html>.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Dan Stewart
+
+Dan Stewart <danielandrewstewart@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by David Golden and Dave Rolsky.
@@ -1528,6 +1644,7 @@ __DATA__
   "odc\@cpan.org" => "oliwer",
   "odyniec\@cpan.org" => "odyniec",
   "olaf\@wundercounter.com" => "oalders",
+  "olaf\@wundersolutions.com" => "oalders",
   "oleg\@cpan.org" => "olegwtf",
   "oliver\@cpan.org" => "ollyg",
   "olof\@cpan.org" => "olof",
@@ -1550,6 +1667,7 @@ __DATA__
   "pattawan\@cpan.org" => "oiami",
   "paul\@pjcj.net" => "pjcj",
   "pause\@sjor.sg" => "sgielen",
+  "pavelsr\@cpan.org" => "pavelsr",
   "pblair\@cpan.org" => "petermblair",
   "pcm\@cpan.org" => "petermartini",
   "pdcawley\@bofh.org.uk" => "pdcawley",
